@@ -690,7 +690,7 @@ core_cpp <- function(x,
 pls.double.cv = function(Xdata,
                          Ydata,
                          constrain=1:nrow(Xdata),
-                         compmax=min(c(ncol(Xdata),nrow(Xdata))),
+                         compmax=min(5,c(ncol(Xdata),nrow(Xdata))),
                          perm.test=FALSE,
                          optim=TRUE,
                          scaling=c("centering","autoscaling"),
@@ -837,7 +837,7 @@ pls.double.cv = function(Xdata,
 knn.double.cv = function(Xdata,
                          Ydata,
                          constrain=1:nrow(Xdata),
-                         compmax=min(c(ncol(Xdata),nrow(Xdata))),
+                         compmax=min(5,c(ncol(Xdata),nrow(Xdata))),
                          perm.test=FALSE,
                          optim=TRUE,
                          scaling=c("centering","autoscaling"),
